The source code

    /*!
     * Ext JS Library 3.3.1
     * Copyright(c) 2006-2010 Sencha Inc.
     * licensing@sencha.com
     * http://www.sencha.com/license
     */
    (function() {
        Ext.override(Ext.list.Column, {
            init : function() {
                var types = Ext.data.Types,
                    st = this.sortType;

                if(this.type){
                    if(Ext.isString(this.type)){
                        this.type = Ext.data.Types[this.type.toUpperCase()] || types.AUTO;
                    }
                }else{
                    this.type = types.AUTO;
                }

                // named sortTypes are supported, here we look them up
                if(Ext.isString(st)){
                    this.sortType = Ext.data.SortTypes[st];
                }else if(Ext.isEmpty(st)){
                    this.sortType = this.type.sortType;
                }
            }
        });

        Ext.tree.Column = Ext.extend(Ext.list.Column, {});
        Ext.tree.NumberColumn = Ext.extend(Ext.list.NumberColumn, {});
        Ext.tree.DateColumn = Ext.extend(Ext.list.DateColumn, {});
        Ext.tree.BooleanColumn = Ext.extend(Ext.list.BooleanColumn, {});

        Ext.reg('tgcolumn', Ext.tree.Column);
        Ext.reg('tgnumbercolumn', Ext.tree.NumberColumn);
        Ext.reg('tgdatecolumn', Ext.tree.DateColumn);
        Ext.reg('tgbooleancolumn', Ext.tree.BooleanColumn);
    })();